@@ -19,11 +19,13 @@
 #define GPARTED_GPARTED_CORE_H
 
 #include "BlockSpecial.h"
+#include "Device.h"
 #include "FileSystem.h"
 #include "Operation.h"
 #include "Partition.h"
 #include "PartitionLUKS.h"
 #include "PartitionVector.h"
+#include "SupportedFileSystems.h"
 #include "Utils.h"
 
 #include <parted/parted.h>
@@ -50,10 +52,8 @@ public:
 	void set_devices( std::vector<Device> & devices ) ;
 	void set_devices_thread( std::vector<Device> * pdevices );
 	void guess_partition_table(const Device & device, Glib::ustring &buff);
-	
-	bool snap_to_cylinder( const Device & device, Partition & partition, Glib::ustring & error ) ;
-	bool snap_to_mebibyte( const Device & device, Partition & partition, Glib::ustring & error ) ;
-	bool snap_to_alignment( const Device & device, Partition & partition, Glib::ustring & error ) ;
+
+	bool valid_partition(const Device& device, Partition& partition, Glib::ustring& error);
 	bool apply_operation_to_disk( Operation * operation );
 
 	bool set_disklabel( const Device & device, const Glib::ustring & disklabel );
@@ -63,7 +63,7 @@ public:
 	bool toggle_flag( const Partition & partition, const Glib::ustring & flag, bool state ) ;
 	
 	const std::vector<FS> & get_filesystems() const ;
-	const FS & get_fs( FSType filesystem ) const;
+	const FS& get_fs(FSType fstype) const;
 	static std::vector<Glib::ustring> get_disklabeltypes() ;
 	std::map<Glib::ustring, bool> get_available_flags( const Partition & partition ) ;
 	Glib::ustring get_thread_status_message() ;
@@ -90,7 +90,7 @@ private:
 	                               std::vector<Glib::ustring> & messages );
 	void set_luks_partition( PartitionLUKS & partition );
 	void set_partition_label_and_uuid( Partition & partition );
-	static FSType detect_filesystem_internal( PedDevice * lp_device, PedPartition * lp_partition );
+	static FSType detect_filesystem_internal(const Glib::ustring& path, Byte_Value sector_size);
 	static FSType detect_filesystem( PedDevice * lp_device, PedPartition * lp_partition,
 	                                 std::vector<Glib::ustring> & messages );
 	void read_label( Partition & partition ) ;
@@ -216,9 +216,6 @@ private:
 	bool update_bootsector( const Partition & partition, OperationDetail & operationdetail ) ;
 
 	//general..	
-	static void init_filesystems();
-	static void fini_filesystems();
-
 	void capture_libparted_messages( OperationDetail & operationdetail, bool success );
 
 	static bool flush_device( PedDevice * lp_device );
@@ -230,18 +227,17 @@ private:
 	static bool commit( PedDisk* lp_disk );
 	static bool commit_to_os( PedDisk* lp_disk, std::time_t timeout );
 	static void settle_device( std::time_t timeout );
-	static bool useable_device( PedDevice * lp_device );
+	static bool useable_device(const PedDevice* lp_device);
 	static PedPartition* get_lp_partition( const PedDisk* lp_disk, const Partition & partition );
 
 	static PedExceptionOption ped_exception_handler( PedException * e ) ;
 
-	std::vector<FS> FILESYSTEMS ;
-	static std::map< FSType, FileSystem * > FILESYSTEM_MAP;
 	std::vector<PedPartitionFlag> flags;
 	std::vector<Glib::ustring> device_paths ;
 	bool probe_devices ;
 	Glib::ustring thread_status_message;  //Used to pass data to show_pulsebar method
 	Glib::RefPtr<Glib::IOChannel> iocInput, iocOutput; // Used to send data to gpart command
+	static SupportedFileSystems* supported_filesystems;
 };
 
 } //GParted
