@@ -95,18 +95,19 @@ enum FSType
 
 	// Other recognised file system types
 	FS_APFS            = 28,
-	FS_BITLOCKER       = 29,
-	FS_GRUB2_CORE_IMG  = 30,
-	FS_ISO9660         = 31,
-	FS_LINUX_SWRAID    = 32,
-	FS_LINUX_SWSUSPEND = 33,
-	FS_REFS            = 34,
-	FS_UFS             = 35,
-	FS_ZFS             = 36,
+	FS_ATARAID         = 29,
+	FS_BITLOCKER       = 30,
+	FS_GRUB2_CORE_IMG  = 31,
+	FS_ISO9660         = 32,
+	FS_LINUX_SWRAID    = 33,
+	FS_LINUX_SWSUSPEND = 34,
+	FS_REFS            = 35,
+	FS_UFS             = 36,
+	FS_ZFS             = 37,
 
 	// Partition space usage colours
-	FS_USED            = 37,
-	FS_UNUSED          = 38
+	FS_USED            = 38,
+	FS_UNUSED          = 39
 } ;
 
 enum SIZE_UNIT
@@ -136,15 +137,15 @@ public:
 	                                           Gtk::IconSize icon_size);
 	static Glib::ustring get_stock_label(const Gtk::StockID& stock_id);
 	static Glib::ustring num_to_str( Sector number ) ;
-	static Glib::ustring get_color( FSType filesystem );
-	static Glib::RefPtr<Gdk::Pixbuf> get_color_as_pixbuf( FSType filesystem, int width, int height );
+	static Glib::ustring get_color(FSType fstype);
+	static Glib::RefPtr<Gdk::Pixbuf> get_color_as_pixbuf(FSType fstype, int width, int height);
 	static int get_max_partition_name_length( Glib::ustring & tabletype );
-	static int get_filesystem_label_maxlength( FSType filesystem );
-	static Glib::ustring get_filesystem_string( FSType filesystem );
+	static int get_filesystem_label_maxlength(FSType fstype);
+	static Glib::ustring get_filesystem_string(FSType fstype);
 	static const Glib::ustring get_encrypted_string();
 	static const Glib::ustring get_filesystem_string( bool encrypted, FSType fstype );
 	static const Glib::ustring get_filesystem_kernel_name( FSType fstype );
-	static Glib::ustring get_filesystem_software( FSType filesystem );
+	static Glib::ustring get_filesystem_software(FSType fstype);
 	static bool kernel_supports_fs( const Glib::ustring & fs ) ;
 	static bool kernel_version_at_least( int major_ver, int minor_ver, int patch_ver ) ;
 	static Glib::ustring format_size( Sector sectors, Byte_Value sector_size ) ;
