@@ -32,17 +32,10 @@ namespace GParted
 class ext2 : public FileSystem
 {
 	const enum FSType specific_type;
-	Glib::ustring dump_cmd;
-	Glib::ustring fsck_cmd;
-	Glib::ustring image_cmd;
-	Glib::ustring label_cmd;
 	Glib::ustring mkfs_cmd;
-	Glib::ustring resize_cmd;
-	Glib::ustring tune_cmd;
+
 public:
-	ext2( enum FSType type ) : specific_type( type ), dump_cmd( "" ), fsck_cmd( "" ), image_cmd( "" ),
-	                               label_cmd( "" ), mkfs_cmd( "" ), resize_cmd( "" ), tune_cmd( "" ),
-	                               force_auto_64bit( false ) {};
+	ext2( enum FSType type ) : specific_type( type ), force_auto_64bit( false )  {};
 	FS get_filesystem_support() ;
 	void set_used_sectors( Partition & partition ) ;
 	void read_label( Partition & partition ) ;
