@@ -15,7 +15,9 @@
  */
 
 #include "DMRaid.h"
+#include "BlockSpecial.h"
 #include "Partition.h"
+#include "Utils.h"
 
 #include <limits.h>
 #include <stdlib.h>		//atoi function
@@ -28,13 +30,29 @@
 namespace GParted
 {
 
+// Data model:
+// dmraid_cache_initialized - Has the cache been loaded?
+// dmraid_found             - Is the "dmraid" command available?
+// dmsetup_found            - Is the "dmsetup" command available?
+// udevadm_found            - Is the "udevadm" command available?
+// dmraid_devices           - Vector of active array names.
+//                            E.g.
+//                            ["isw_ecccdhhiga_MyArray"]
+// dmraid_member_cache      - Vector of members of active DMRaid arrays.
+//                            E.g.
+//                            //member                  , array
+//                            [{BlockSpecial("/dev/sdc"), "/dev/mapper/isw_ecccdhhiga_MyArray"},
+//                             {BlockSpecial("/dev/sdd"), "/dev/mapper/isw_ecccdhhiga_MyArray"}
+//                            ]
+
 //Initialize static data elements
 bool DMRaid::dmraid_cache_initialized = false ;
 bool DMRaid::dmraid_found  = false ;
 bool DMRaid::dmsetup_found = false ;
-bool DMRaid::udevinfo_found = false ;
 bool DMRaid::udevadm_found  = false ;
 std::vector<Glib::ustring> DMRaid::dmraid_devices ;
+std::vector<DMRaid_Member> DMRaid::dmraid_member_cache;
+
 
 DMRaid::DMRaid()
 {
@@ -68,10 +86,11 @@ DMRaid::~DMRaid()
 
 void DMRaid::load_dmraid_cache()
 {
-	//Load data into dmraid structures
 	Glib::ustring output, error ;
 	dmraid_devices .clear() ;
+	dmraid_member_cache.clear();
 
+	// Load active DMRaid array names.
 	if ( dmraid_found )
 	{
 		if ( ! Utils::execute_command( "dmraid -sa -c", output, error, true ) )
@@ -80,14 +99,27 @@ void DMRaid::load_dmraid_cache()
 				Utils::tokenize( output, dmraid_devices, "\n" ) ;
 		}
 	}
+
+	// Load members of active DMRaid arrays.
+	for (unsigned int i = 0; i < dmraid_devices.size(); i++)
+	{
+		std::vector<Glib::ustring> members = lookup_dmraid_members(DEV_MAPPER_PATH + dmraid_devices[i]);
+		for (unsigned int j = 0; j < members.size(); j++)
+		{
+			DMRaid_Member memb;
+			memb.member = BlockSpecial(members[j]);
+			memb.array  = DEV_MAPPER_PATH + dmraid_devices[i];
+			dmraid_member_cache.push_back(memb);
+		}
+	}
 }
 
+
 void DMRaid::set_commands_found()
 {
 	//Set status of commands found 
 	dmraid_found = (! Glib::find_program_in_path( "dmraid" ) .empty() ) ;
 	dmsetup_found = (! Glib::find_program_in_path( "dmsetup" ) .empty() ) ;
-	udevinfo_found = (! Glib::find_program_in_path( "udevinfo" ) .empty() ) ;
 	udevadm_found = (! Glib::find_program_in_path( "udevadm" ) .empty() ) ;
 }
 
@@ -249,10 +281,7 @@ Glib::ustring DMRaid::get_udev_dm_name( const Glib::ustring & dev_path )
 	Glib::ustring error  = "" ;
 	Glib::ustring dm_name = "" ;
 
-	if ( udevinfo_found )
-		Utils::execute_command( "udevinfo --query=all --name=" + Glib::shell_quote( dev_path ),
-		                        output, error, true );
-	else if ( udevadm_found )
+	if (udevadm_found)
 		Utils::execute_command( "udevadm info --query=all --name=" + Glib::shell_quote( dev_path ),
 		                        output, error, true );
 
@@ -497,4 +526,86 @@ bool DMRaid::update_dev_map_entry( const Partition & partition, OperationDetail
 	return exit_status ;
 }
 
+
+// Return whether the named device (e.g. "/dev/sdc") is a member of a DMRaid array or not.
+bool DMRaid::is_member(const Glib::ustring& member_path)
+{
+	const DMRaid_Member& memb = get_cache_entry_by_member(member_path);
+	if (memb.member.m_name.length() > 0)
+		return true;
+
+	return false;
+}
+
+// Return whether the named device (e.g. "/dev/sdc") is a member of an *active* DMRaid
+// array or not.
+// As the cache only records members of active DMRaid arrays:
+//     is_member_active(x) == is_member(x)
+bool DMRaid::is_member_active(const Glib::ustring& member_path)
+{
+	return is_member(member_path);
+}
+
+
+// Return array device containing the specified member, or "" if the array is not running
+// or there is no such member.
+const Glib::ustring& DMRaid::get_array(const Glib::ustring& member_path)
+{
+	const DMRaid_Member& memb = get_cache_entry_by_member(member_path);
+	return memb.array;
+}
+
+
+// Return vector of member devices of an active DMRaid array.
+// E.g. lookup_dmraid_members("/dev/mapper/isw_ecccdhhiga_MyArray") -> ["/dev/sdc", "/dev/sdd"]
+std::vector<Glib::ustring> DMRaid::lookup_dmraid_members(const Glib::ustring& array)
+{
+	// Method:
+	// (1) Query udev for the kernel device name;
+	// (2) List member names from the directory /sys/block/${name}/slaves.
+
+	std::vector<Glib::ustring> members;
+	if (! udevadm_found)
+		return members;  // Empty vector
+
+	Glib::ustring output;
+	Glib::ustring error;
+	Utils::execute_command("udevadm info --query=name " + Glib::shell_quote(array),
+	                       output, error, true);
+
+	// Strip terminating new line from output.
+	size_t len = output.length();
+	if (len > 0 && output[len-1] == '\n')
+		output.resize(len-1);
+
+	if (output.empty())
+		return members;  // Empty vector
+
+	Glib::ustring filename;
+	Glib::Dir dir("/sys/block/" + output + "/slaves");
+	while ((filename = dir.read_name()) != "")
+	{
+		members.push_back("/dev/" + filename);
+	}
+
+	return members;
+}
+
+
+// Perform linear search of the cache to find the matching member.
+// Return found cache entry or not found substitute.
+const DMRaid_Member& DMRaid::get_cache_entry_by_member(const Glib::ustring& member_path)
+{
+	BlockSpecial bs = BlockSpecial(member_path);
+	for (unsigned int i = 0; i < dmraid_member_cache.size(); i++)
+	{
+		if (bs == dmraid_member_cache[i].member)
+			return dmraid_member_cache[i];
+	}
+
+	static const DMRaid_Member notfound_memb = {BlockSpecial(), ""};
+	return notfound_memb;
+}
+
+
 }//GParted
