@@ -28,17 +28,16 @@ namespace GParted
 Dialog_Partition_Name::Dialog_Partition_Name( const Partition & partition, int max_length )
 {
 	this->set_resizable( false );
-	this->set_has_separator( false );
 	this->set_size_request( 400, -1 );
 
 	/* TO TRANSLATORS: dialog title, looks like   Set partition name on /dev/hda3 */
-	this->set_title( String::ucompose( _("Set partition name on %1"), partition.get_path() ) );
+	this->set_title( Glib::ustring::compose( _("Set partition name on %1"), partition.get_path() ) );
 
-	// HBox to hole the label and entry box line
-	Gtk::HBox *hbox( manage( new Gtk::HBox() ) );
+	// Horizontal box to hold the label and entry box line
+	Gtk::Box *hbox(manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL)));
 	hbox->set_border_width( 5 );
 	hbox->set_spacing( 10 );
-	get_vbox()->pack_start( *hbox, Gtk::PACK_SHRINK );
+	get_content_area()->pack_start(*hbox, Gtk::PACK_SHRINK);
 
 	// Only line: "Name: [EXISTINGNAME  ]"
 	hbox->pack_start( *Utils::mk_label( "<b>" + Glib::ustring(_("Name:")) + "</b>" ),
