@@ -19,6 +19,10 @@
 
 #include <cerrno>
 #include <iostream>
+#include <glibmm/miscutils.h>
+#include <glibmm/stringutils.h>
+#include <glibmm/shell.h>
+#include <glibmm/main.h>
 #include <gtkmm/main.h>
 #include <signal.h>
 #include <fcntl.h>
@@ -212,7 +216,7 @@ Glib::ustring FileSystem::mk_temp_dir( const Glib::ustring & infix, OperationDet
 	{
 		int e = errno ;
 		operationdetail .get_last_child() .add_child( OperationDetail(
-				String::ucompose( "mkdtemp(%1): %2", dir_buf, Glib::strerror( e ) ), STATUS_NONE ) ) ;
+				Glib::ustring::compose( "mkdtemp(%1): %2", dir_buf, Glib::strerror( e ) ), STATUS_NONE ) ) ;
 		operationdetail.get_last_child().set_success_and_capture_errors( false );
 		dir_name = "" ;
 	}
@@ -223,7 +227,7 @@ Glib::ustring FileSystem::mk_temp_dir( const Glib::ustring & infix, OperationDet
 				Glib::ustring( "mkdir -v " ) + dir_name, FONT_BOLD_ITALIC ) ;
 		operationdetail .get_last_child() .add_child( OperationDetail(
 				/*TO TRANSLATORS: looks like   Created directory /tmp/gparted-CEzvSp */
-				String::ucompose( _("Created directory %1"), dir_name ), STATUS_NONE ) ) ;
+				Glib::ustring::compose( _("Created directory %1"), dir_name ), STATUS_NONE ) ) ;
 		operationdetail.get_last_child().set_success_and_capture_errors( true );
 	}
 
@@ -242,14 +246,14 @@ void FileSystem::rm_temp_dir( const Glib::ustring dir_name, OperationDetail & op
 		//  failed.  Set to Warning (N/A) instead.
 		int e = errno ;
 		operationdetail .get_last_child() .add_child( OperationDetail(
-				String::ucompose( "rmdir(%1): ", dir_name ) + Glib::strerror( e ), STATUS_NONE ) ) ;
+				Glib::ustring::compose( "rmdir(%1): ", dir_name ) + Glib::strerror( e ), STATUS_NONE ) ) ;
 		operationdetail.get_last_child().set_status( STATUS_WARNING );
 	}
 	else
 	{
 		operationdetail .get_last_child() .add_child( OperationDetail(
 				/*TO TRANSLATORS: looks like   Removed directory /tmp/gparted-CEzvSp */
-				String::ucompose( _("Removed directory %1"), dir_name ), STATUS_NONE ) ) ;
+				Glib::ustring::compose( _("Removed directory %1"), dir_name ), STATUS_NONE ) ) ;
 		operationdetail.get_last_child().set_success_and_capture_errors( true );
 	}
 }
