@@ -15,13 +15,16 @@
  */
 
 #include "HBoxOperations.h"
+#include "MenuHelpers.h"
+#include "Utils.h"
 
 #include <gtkmm/stock.h>
 
 namespace GParted
 {
 
-HBoxOperations::HBoxOperations() 
+HBoxOperations::HBoxOperations()
+ : Gtk::Box(Gtk::ORIENTATION_HORIZONTAL)
 {
 	//create listview for pending operations
 	liststore_operations = Gtk::ListStore::create( treeview_operations_columns );
@@ -40,27 +43,35 @@ HBoxOperations::HBoxOperations()
 	pack_start( scrollwindow, Gtk::PACK_EXPAND_WIDGET );
 
 	//create popupmenu
-	menu_popup .items() .push_back( Gtk::Menu_Helpers::ImageMenuElem( 
+	Gtk::MenuItem *item;
+	item = manage(new GParted::Menu_Helpers::ImageMenuElem(
 		_("_Undo Last Operation"), 
-		* manage( new Gtk::Image( Gtk::Stock::UNDO, Gtk::ICON_SIZE_MENU ) ), 
-		sigc::mem_fun(*this, &HBoxOperations::on_undo) ) );
+		*Utils::mk_image(Gtk::Stock::UNDO, Gtk::ICON_SIZE_MENU),
+		sigc::mem_fun(*this, &HBoxOperations::on_undo)));
+	menu_popup.append(*item);
+	menu_popup_items[0] = item;
 
-	menu_popup .items() .push_back( Gtk::Menu_Helpers::ImageMenuElem( 
+	item = manage(new GParted::Menu_Helpers::ImageMenuElem(
 		_("_Clear All Operations"), 
-		* manage( new Gtk::Image( Gtk::Stock::CLEAR, Gtk::ICON_SIZE_MENU ) ), 
-		sigc::mem_fun(*this, &HBoxOperations::on_clear) ) );
+		*Utils::mk_image(Gtk::Stock::CLEAR, Gtk::ICON_SIZE_MENU),
+		sigc::mem_fun(*this, &HBoxOperations::on_clear)));
+	menu_popup.append(*item);
+	menu_popup_items[1] = item;
 
-	menu_popup .items() .push_back( Gtk::Menu_Helpers::ImageMenuElem( 
+	item = manage(new GParted::Menu_Helpers::ImageMenuElem(
 		_("_Apply All Operations"), 
-		* manage( new Gtk::Image( Gtk::Stock::APPLY, Gtk::ICON_SIZE_MENU ) ), 
-		sigc::mem_fun(*this, &HBoxOperations::on_apply) ) );
+		*Utils::mk_image(Gtk::Stock::APPLY, Gtk::ICON_SIZE_MENU),
+		sigc::mem_fun(*this, &HBoxOperations::on_apply)));
+	menu_popup.append(*item);
+	menu_popup_items[2] = item;
 
-	menu_popup .items() .push_back( Gtk::Menu_Helpers::SeparatorElem() );
-	menu_popup .items() .push_back( Gtk::Menu_Helpers::StockMenuElem( 
-		Gtk::Stock::CLOSE, sigc::mem_fun(*this, &HBoxOperations::on_close) ) );
+	menu_popup.append(*manage(new GParted::Menu_Helpers::SeparatorElem()));
+	menu_popup.append(*manage(new GParted::Menu_Helpers::StockMenuElem(
+		Gtk::Stock::CLOSE, sigc::mem_fun(*this, &HBoxOperations::on_close))));
 }
 
-void HBoxOperations::load_operations( const std::vector<Operation *> operations ) 
+
+void HBoxOperations::load_operations(const std::vector<Operation *>& operations)
 {
 	liststore_operations ->clear();
 
@@ -88,9 +99,9 @@ bool HBoxOperations::on_signal_button_press_event( GdkEventButton * event )
 	//right-click
 	if ( event ->button == 3 )
 	{
-		menu_popup .items()[0] .set_sensitive( liststore_operations ->children() .size() > 0 ) ;
-		menu_popup .items()[1] .set_sensitive( liststore_operations ->children() .size() > 0 ) ;
-		menu_popup .items()[2] .set_sensitive( liststore_operations ->children() .size() > 0 ) ;
+		menu_popup_items[0]->set_sensitive(liststore_operations->children().size() > 0);
+		menu_popup_items[1]->set_sensitive(liststore_operations->children().size() > 0);
+		menu_popup_items[2]->set_sensitive(liststore_operations->children().size() > 0);
 
 		menu_popup .popup( event ->button, event ->time ) ;
 	}
